Here is an unordered list:
- An item
- Another item
- A third item

This is an unordered list using different prefixes:
+ An item
- Another item
* A third item

Here is an ordered list:
1. My first item
2. My second item
3. My third item
4. And one more, why not?
